Vim-style prompt editing engine shared by VT Code terminal surfaces.
Structs
- Handle
KeyOutcome - Result of routing a single key through the Vim engine.
- VimState
Enums
- VimMode
- Active Vim editing mode.
Traits
- Editor
- Minimal text-editor surface required by the Vim engine.
Functions
- handle_
key - Apply a single key event to the Vim state and editor surface.